==> cypress-2021.2.0.zip: cypress/README.md <==
# Cypress

http://cdevroe.com/projects/cypress

A portfolio theme.

By: [Colin Devroe](http://cdevroe.com) & [Kyle Ruane](http://kyleruane.com)

Send suggestions and bugs to colin@cdevroe.com

-----

## Installation

1. Log into WordPress Admin
2. Choose Appearance > Themes > Add New > Upload Theme
3. Upload cypress.zip
4. Once uploaded, Activate theme

### Setup

(Coming soon, a video walk-through of setting up Cypress)

1. Remain logged into WordPress, navigate to your website home page.
2. Choose Customize from the menu at the top of the page
3. Under Site Identity, update Site Title and Tagline.
4. Under Menus, if you don't have a menu, click "Create Menu", name it anything and choose "Primary Menu". Click Next. Choose Add Items. Add your Homepage. If you have a "Blog" page, add that to your menu. If you do not. Add one. If you do not have a "Portfolio" page, add one.
5. Under Homepage Settings, choose "A static page". For Homepage choose your Portfolio page. For Posts page choose your Blog page.
6. Under Cypress Options, add any social networking accounts you'd like (more are coming). Also update your footer text.
7. Go into your WordPress Admin, choose Settings > Permalinks and choose the Permalink Settings you'd like. Any of them will work. And click Save Changes. 

That's it! Your web site is setup. You can add as many Blog Posts, Portfolio pieces, and Pages as you'd like!

### Adding Portfolio Items

1. Log into WordPress Admin
2. Choose Portfolio > Add New
3. Consider adding a Category for your Portfolio piece. Example: For Photographers, you might add Portraits, Landscapes, Wedding, Architecture, Street, Etc.
4. Add a Featured Image on the bottom right. This is the image that will appear on the homepage. The visitor of your site will click on this image to view the Portfolio Item.
5. Add a title. This appears at the bottom of the Portfolio item.
6. Add any content, including galleries, multiple images, text, video, etc.

-----

## Known Issues or Feature Roadmap


- Fix: Reduce code
- Fix: Several issues to resolve within Theme Check
- New: Place cursor in search box when clicked
- New: EZ Digital Downloads support (mostly styles)



-----

## Version History

Version numbers are YYYY.RELEASE.FIX

See readme.txt

==> cypress-2021.5.1.zip: cypress/README.md <==
# Cypress

http://cdevroe.com/projects/cypress

A portfolio theme.

By: [Colin Devroe](http://cdevroe.com) & [Kyle Ruane](http://kyleruane.com)

Send suggestions and bugs to colin@cdevroe.com

---

## Installation

1. Log into WordPress Admin
2. Choose Appearance > Themes > Add New > Upload Theme
3. Upload cypress.zip
4. Once uploaded, Activate theme

### Setup

[Watch a video walkthrough](https://youtu.be/oZrkRB2_x8Y)

1. Remain logged into WordPress, navigate to your website home page.
2. Choose Customize from the menu at the top of the page
3. Under Site Identity, update Site Title and Tagline.
4. Under Menus, if you don't have a menu, click "Create Menu", name it anything and choose "Primary Menu". Click Next. Choose Add Items. Add your Homepage. If you have a "Blog" page, add that to your menu. If you do not. Add one. If you do not have a "Portfolio" page, add one.
5. Under Homepage Settings, choose "A static page". For Homepage choose your Portfolio page. For Posts page choose your Blog page.
6. Under Cypress Options, add any social networking accounts you'd like (more are coming). Also update your footer text.
7. Go into your WordPress Admin, choose Settings > Permalinks and choose the Permalink Settings you'd like. Any of them will work. And click Save Changes.

That's it! Your web site is setup. You can add as many Blog Posts, Portfolio pieces, and Pages as you'd like!

### Adding Portfolio Items

1. Log into WordPress Admin
2. Choose Portfolio > Add New
3. Consider adding a Category for your Portfolio piece. Example: For photographers, you might add Portraits, Landscapes, Wedding, Architecture, Street, Etc.
4. Add a Featured Image on the bottom right of the WordPress post edit screen. This is the image that will appear on the homepage. The visitor of your site will click on this image to view the Portfolio Item. It is recommended that this image be at least 600px wide.
5. Add a title. This appears at the bottom of the Portfolio item.
6. Add any content, including galleries, multiple images, text, video, etc. Images added to portfolio items should be around 1800px wide as they can be viewed at any size.

---

## Known Issues or Feature Roadmap

- Fix: Reduce code
- Fix: Several issues to resolve within Theme Check
- New: Place cursor in search box when clicked
- New: EZ Digital Downloads support (mostly styles)

---

## Version History

Version numbers are YYYY.RELEASE.FIX

See readme.txt
